(function( $ ) {
	'use strict';

	jQuery( document ).ready( function( $ ) {

		// Klaviyo license button
		$( document ).on( 'click', '.klaviyo-edd-license-btn', function() {

			var button_name = $( this ).attr( 'name' );
			var data = {
				action: 'kt_license_button',
				button_name: button_name
			};
			$.ajax( {
				type: 'post',
				url: klaviyoAdminAjax.ajaxurl,
				data: data,
				beforeSend: function() {
					$( '.klaviyo-admin-loader' ).show();
					$( '.klaviyo-license-table' ).addClass( 'klaviyo-fade-table' );
				},
				complete: function( response ) {
					$( '.klaviyo-license-table' ).removeClass( 'klaviyo-fade-table' );
					$( '.klaviyo-admin-loader' ).hide();
				},
				success: function( response ) {
					var redirectUrl = response.redirect_url,
						klaviyo_activation_flag = response.sl_activation,
						klaviyo_activation_msg = response.message;

					if ( 'false' === klaviyo_activation_flag ) {
						$( '.klaviyo-license-msg' ).html( '<div class="error"><p>' + klaviyo_activation_msg + '</p></div>' );
					} else {
						$( '.klaviyo-license-msg' ).html( '<div class="notice"><p>' + klaviyo_activation_msg + '</p></div>' );
					}

					window.location.href = redirectUrl;
				}
			} );

		} );
		
		$('.export-subscriptions-button').on('click', function(e) {
			e.preventDefault();
			$(this).prop('disabled', true);
			$('.export-progress-container').show();
			processBatch(0);
		});
		
		function processBatch(offset) {
			var selectedProducts = $('#subscription_products').val(); // Get selected products
			$.ajax({
				url: ajaxurl,
				method: 'POST',
				data: {
					action: 'download_wc_subscriptions',
					offset: offset,
					selected_products: selectedProducts // Pass selected products to the AJAX request
				},
				success: function(response) {
					var progress = parseFloat(response.progress);
					if (!isNaN(progress)) {
						$("#exportProgressBar > div").css("width", progress + "%").text(progress + "%");
						if(response.hasMore) {
							processBatch(response.nextOffset);
						} else {
							// Fetch the download link first
							fetchDownloadLink(function() {
								// Once the download link is fetched, finish the export
								$.post(ajaxurl, { action: 'finish_export' });
							});
						}
					}
				},
				error: function(err) {
					alert('There was an error processing the request. Please try again.');
				}
			});
		}
		
		function fetchDownloadLink(callback) {
			$.ajax({
				url: ajaxurl,
				method: 'POST',
				data: {
					action: 'get_exported_file_url'
				},
				success: function(response) {
					if (response.success && response.data && response.data.file && !$('.download-link').length) {
						var downloadLink = "<br><a class='button button-primary export-subscriptions-button download-link' href='" + response.data.file + "'>Download CSV</a>";
						$('#exportProgressBar').after(downloadLink);
						if (callback) {
							callback();
						}
					}
				}
			});
		}
		
		$('#subscription_products').select2({
			ajax: {
				url: ajaxurl,
				dataType: 'json',
				delay: 250,
				data: function(params) {
					return {
						q: params.term, // search term
						action: 'get_subscription_products'
					};
				},
				processResults: function(data) {
					return {
						results: data.data.results
					};
				},
				cache: true
			},
			minimumInputLength: 2,
			placeholder: 'Search for a subscription product',
			allowClear: true
		});
		
	} );

})( jQuery );
