<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class KT_Klaviyo_General_Events {
	private $klaviyoService;

	public function __construct($klaviyoService) {
		$this->klaviyoService = $klaviyoService;
		add_action('woocommerce_new_customer_note', array($this, 'klaviyo_customer_note_added'));
	}

	public function sendViewedPageEvent($pageDetails) {
		$eventDetails = [
			'properties' => [
				'PageID' => $pageDetails['id'],
				'PageName' => $pageDetails['title'],
				'URL' => $pageDetails['url']
			],
			'metric_name' => 'Viewed Page',
			'customer_properties' => [
				'$email' => $pageDetails['email']
			]
		];

		$this->klaviyoService->sendEvent($eventDetails);
	}

	public function sendSearchedSiteEvent($searchDetails) {
		$eventDetails = [
			'properties' => [
				'SearchTerm' => $searchDetails['query'],
				'ReturnedResults' => $searchDetails['total_results'],
				'SearchResultsUrl' => $searchDetails['results_url']
			],
			'metric_name' => 'Searched Site',
			'customer_properties' => [
				'$email' => $searchDetails['email']
			]
		];

		$this->klaviyoService->sendEvent($eventDetails);
	}

	public function sendViewedProductCategoryEvent($categoryDetails) {
		$eventDetails = [
			'properties' => [
				'ProductCategoryName' => $categoryDetails['categoryName'],
				'ProductCategoryID' => $categoryDetails['categoryID'],
				'ImageURL' => $categoryDetails['imageURL'],
				'URL' => $categoryDetails['url'],
			],
			'metric_name' => 'Viewed Product Category',
			'customer_properties' => [
				'$email' => $categoryDetails['email']
			]
		];

		$this->klaviyoService->sendEvent($eventDetails);
	}

	public function sendViewedPostEvent($postDetails) {
		$eventDetails = [
			'properties' => [
				'PostName' => $postDetails['postTitle'],
				'PostID' => $postDetails['postID'],
				'PostCategory' => $postDetails['postCategories'],
				'ImageURL' => $postDetails['imageURL'],
				'URL' => $postDetails['url'],
			],
			'metric_name' => 'Viewed Post',
			'customer_properties' => [
				'$email' => $postDetails['email']
			]
		];

		$this->klaviyoService->sendEvent($eventDetails);
	}

	public function klaviyo_customer_note_added($args) {
		$klaviyo_license_status = get_option('klaviyo_edd_license_status');
		$klaviyo_order_note = get_option('klaviyo_order_note');

		if ('enabled' === $klaviyo_order_note && 'valid' === $klaviyo_license_status) {
			$order = wc_get_order($args['order_id']);
			if ($order) {
				$customer_email = $order->get_billing_email();

				$note_event_details = array(
					'OrderID' => $args['order_id'],
					'Note' => $args['customer_note']
				);

				// Send event to Klaviyo
				$this->klaviyoService->sendEvent(array(
					'properties' => $note_event_details,
					'metric_name' => 'Order Note Added',
					'customer_properties' => array(
						'$email' => $customer_email
					)
				));
			} else {
				Klaviyo_Toolkit::log_message('Order not found for order ID: ' . $args['order_id']);
			}
		} else {
			Klaviyo_Toolkit::log_message('Order note is not enabled or the license is not valid.');
		}
	}
}
