<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

use KlaviyoAPI\KlaviyoAPI;

class KT_Klaviyo_Service {
	private $client;

	public function __construct($apiKey, $guzzleOptions = [], $userAgentSuffix = '/klaviyo-toolkit') {
		$this->client = new KlaviyoAPI($apiKey, 3, 3, $guzzleOptions, $userAgentSuffix);
	}

	public static function generate_uuid_v4() {
		return sprintf('%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
			mt_rand(0, 0xffff), mt_rand(0, 0xffff),
			mt_rand(0, 0xffff),
			mt_rand(0, 0x0fff) | 0x4000,
			mt_rand(0, 0x3fff) | 0x8000,
			mt_rand(0, 0xffff), mt_rand(0, 0xffff), mt_rand(0, 0xffff)
		);
	}

	public function sendEvent($eventDetails) {
		try {
			$this->client->Events->createEvent([
				'data' => [
					'type' => 'event',
					'attributes' => [
						'properties' => $eventDetails['properties'],
						'metric' => [
							'data' => [
								'type' => 'metric',
								'attributes' => [
									'name' => $eventDetails['metric_name']
								]
							]
						],
						'profile' => [
							'data' => [
								'type' => 'profile',
								'attributes' => [
									'email' => $eventDetails['customer_properties']['$email']
								]
							]
						],
						'unique_id' => $this->generate_uuid_v4()
					]
				]
			]);
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error sending event to Klaviyo: ' . $e->getMessage());
		}
	}

	public function getProfileIdByEmail($email) {
		$filter = "equals(email,\"$email\")";
		try {
			$response = $this->client->Profiles->getProfiles(null, null, $filter);
			if (!empty($response['data']) && !empty($response['data'][0]['id'])) {
				return $response['data'][0]['id'];
			}
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error fetching profile from Klaviyo: ' . $e->getMessage());
			return null;
		}
		return null;
	}

	public function updateProfileByEmail($email, $attributes) {
		$profileId = $this->getProfileIdByEmail($email);
		if (!$profileId) {
			$message = "No profile found for email: $email";
			Klaviyo_Toolkit::log_message($message);
			throw new Exception($message);
		}
		$this->updateProfile($profileId, $attributes);
	}

	public function updateProfile($profileId, $attributes) {
		$updateData = [
			'data' => [
				'type' => 'profile',
				'id' => $profileId,
				'attributes' => [
					'properties' => $attributes
				]
			]
		];
		try {
			$this->client->Profiles->updateProfile($profileId, $updateData);
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error updating profile in Klaviyo: ' . $e->getMessage());
			throw $e;
		}
	}
}