<?php

/**
 * The Klaviyo Toolkit main plugin file
 *
 * @link              https://madebytribe.com
 * @since             1.0.0
 * @package           Klaviyo_Toolkit
 *
 * @wordpress-plugin
 * Plugin Name:       Klaviyo Toolkit
 * Plugin URI:        https://madebytribe.com
 * Description:       Send additional key metrics events from WooCommerce to Klaviyo, WooCommerce Subscription statuses, create abandoned cart coupons and more.
 * Version:           1.8.1
 * Author:            Tribe Interactive, LLC
 * Author URI:        https://madebytribe.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       klaviyo-toolkit
 * Domain Path:       /languages
 *
 * WC requires at least: 8.0
 * WC tested up to: 8.9.1
 *
 * ████████ ██████  ██ ██████  ███████ 
 *	  ██    ██   ██ ██ ██   ██ ██      
 *	  ██    ██████  ██ ██████  █████   
 *	  ██    ██   ██ ██ ██   ██ ██      
 *	  ██    ██   ██ ██ ██████  ███████ 
 *									 
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if (version_compare(PHP_VERSION, '7.4', '<')) {
	if (is_admin() && (!defined('DOING_AJAX') || !DOING_AJAX)) {
		add_action('admin_notices', function() {
			echo '<div class="error"><p>' . esc_html__('Klaviyo Toolkit requires PHP version 7.4 or higher. Please update your PHP version to activate the plugin.', 'klaviyo-toolkit') . '</p></div>';
		});
	}
	return;
}

/**
 * Define constants
 */
define( 'KLAVIYO_TOOLKIT_EDD_STORE_URL', 'https://www.madebytribe.com' );
define( 'KLAVIYO_TOOLKIT_EDD_ITEM_ID', 16543 );
define( 'KLAVIYO_TOOLKIT_EDD_ITEM_NAME', 'Klaviyo Toolkit Plugin' );
define( 'KLAVIYO_TOOLKIT_VERSION', '1.8.1' );
define( 'KLAVIYO_TOOLKIT_AUTHOR', 'Tribe Interactive, LLC' );

/**
 * Load composer packages
 */
require_once( 'vendor/autoload.php' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-klaviyo-toolkit-activator.php
 */
function activate_klaviyo_toolkit() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-kt-activator.php';
	Klaviyo_Toolkit_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-klaviyo-toolkit-deactivator.php
 */
function deactivate_klaviyo_toolkit() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-kt-deactivator.php';
	Klaviyo_Toolkit_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_klaviyo_toolkit' );
register_deactivation_hook( __FILE__, 'deactivate_klaviyo_toolkit' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-kt.php';

/**
 * Load license check
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-kt-license.php';

/**
 * Load EDD updater if it doesn't already exist
 */
require( plugin_dir_path( __FILE__ ) . 'includes/class-kt-updater.php' );

/**
 * The plugin class runs plugin notices
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-kt-notices.php';

/**
 * Load dismissible notices library
 */
require plugin_dir_path( __FILE__ ) . 'vendor/collizo4sky/persist-admin-notices-dismissal/persist-admin-notices-dismissal.php';

/**
 * Declare HPOS compatibility
 */
add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_klaviyo_toolkit() {

	$plugin = new Klaviyo_Toolkit();
	$plugin->run();

}
run_klaviyo_toolkit();

/**
 * Initialize the updater. Hooked into `init` to work with the
 * wp_version_check cron job, which allows auto-updates.
 */
function klaviyo_toolkit_edd_updater() {

	// To support auto-updates, this needs to run during the wp_version_check cron job for privileged users.
	$doing_cron = defined( 'DOING_CRON' ) && DOING_CRON;
	if ( ! current_user_can( 'manage_options' ) && ! $doing_cron ) {
		return;
	}

	$license_key = trim( get_option( 'klaviyo_edd_license_key' ) );

	// setup the updater
	$edd_updater = new KT_EDD_Updater( KLAVIYO_TOOLKIT_EDD_STORE_URL, __FILE__,
		array(
			'version' => KLAVIYO_TOOLKIT_VERSION,
			'license' => $license_key,
			'item_id' => KLAVIYO_TOOLKIT_EDD_ITEM_ID,
			'author'  => KLAVIYO_TOOLKIT_AUTHOR,
			'beta'    => false,
		)
	);

}
add_action( 'init', 'klaviyo_toolkit_edd_updater' );